summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/pilot.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/pilot.h')
-rw-r--r--kpilot/lib/pilot.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/kpilot/lib/pilot.h b/kpilot/lib/pilot.h
index d4fec82b..3ac2918b 100644
--- a/kpilot/lib/pilot.h
+++ b/kpilot/lib/pilot.h
@@ -35,9 +35,9 @@
#include <pi-buffer.h>
#include <pi-dlp.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqvaluelist.h>
#include "pilotLinkVersion.h"
@@ -77,38 +77,38 @@ namespace Pilot
/** Maximum size (in bytes) of a record's data */
static const int MAX_RECORD_SIZE = 65535;
- typedef QValueList<recordid_t> RecordIDList;
+ typedef TQValueList<recordid_t> RecordIDList;
/** Static translation function that maps handheld native (8 bit,
* usually latin1 but sometimes someting else) encoded data to
* a Unicode string. Converts the @p len characters in @p c
* to a Unicode string.
*/
- QString fromPilot( const char *c, int len );
+ TQString fromPilot( const char *c, int len );
/** Static translation function mapping a NUL-terminated
* string from the handheld's encoding to UTF-8.
* @param c the NUL-terminated string to decode
* @return QString (UTF-8) value of @p c
* @note NUL-terminated strings are rare on the handheld.
*/
- QString fromPilot( const char *c );
+ TQString fromPilot( const char *c );
- /** Static translation function that maps a QString onto the
+ /** Static translation function that maps a TQString onto the
* native 8 bit encoding of the handheld. Writes the result into
* the buffer @p buf which has size @p len. Returns the length
* of the result. Zero-fills the buffer as needed.
*/
- int toPilot( const QString &s, char *buf, int len);
- int toPilot( const QString &s, unsigned char *buf, int len);
+ int toPilot( const TQString &s, char *buf, int len);
+ int toPilot( const TQString &s, unsigned char *buf, int len);
- /** Static translation function that maps a QString onto the
+ /** Static translation function that maps a TQString onto the
* native 8 bit encoding of the handheld.
*
* @param s String to encode
* @return Encoded string in a QCString
*/
- QCString toPilot( const QString &s );
+ TQCString toPilot( const TQString &s );
/** Create a codec for translating handheld native 8 bit to Unicode,
* using the given codec @p name -- this will often be latin1, but
@@ -117,10 +117,10 @@ namespace Pilot
*
* @return @c true on success, @c false otherwise
*/
- bool setupPilotCodec(const QString &name);
+ bool setupPilotCodec(const TQString &name);
/** Returns the name of the codec being used. */
- QString codecName();
+ TQString codecName();
/** For debugging, display category names for the given AppInfo
* structure. Called by dump(). You must pass a valid reference.
@@ -140,12 +140,12 @@ namespace Pilot
return ((unsigned int)c<CATEGORY_COUNT);
}
/** Returns the QString for the requested category @p i
* in the category structure @p info. Returns @c QString::null
* on error (bad pointer or bad category number). May also
* return @c QString::null if the category name is empty.
*/
- inline QString categoryName(const struct CategoryAppInfo *info, unsigned int i)
+ inline TQString categoryName(const struct CategoryAppInfo *info, unsigned int i)
{
if ( ( i < CATEGORY_COUNT ) && ( info->name[i][0] ) )
{
@@ -157,7 +157,7 @@ namespace Pilot
}
else
{
- return QString::null;
+ return TQString::null;
}
}
@@ -166,16 +166,16 @@ namespace Pilot
* all sixteen categories -- empty category names on the
* handheld are skipped.
*/
- inline QStringList categoryNames(const struct CategoryAppInfo *info)
+ inline TQStringList categoryNames(const struct CategoryAppInfo *info)
{
- QStringList l;
+ TQStringList l;
if (!info)
{
return l;
}
for (unsigned int i=0; i<CATEGORY_COUNT; ++i)
{
- QString s = categoryName(info,i);
+ TQString s = categoryName(info,i);
if (!s.isEmpty())
{
l.append(s);
@@ -198,7 +198,7 @@ namespace Pilot
* @p unknownIsUnfiled is true.
*
*/
- int findCategory(const struct CategoryAppInfo *info, const QString &name, bool unknownIsUnfiled);
+ int findCategory(const struct CategoryAppInfo *info, const TQString &name, bool unknownIsUnfiled);
/** Search for the given category @p name in the list
* of categories; returns the category number. If @p unknownIsUnfiled
@@ -218,7 +218,7 @@ namespace Pilot
* are all full.
*
*/
- int insertCategory(struct CategoryAppInfo *info, const QString &label, bool unknownIsUnfiled);
+ int insertCategory(struct CategoryAppInfo *info, const TQString &label, bool unknownIsUnfiled);
/** The handheld also holds data about each database
* in a DBInfo structure; check if the database described
@@ -77,38 +77,38 @@ namespace Pilot
* string from the handheld's encoding to UTF-8.
* @param c the NUL-terminated string to decode
- * @return QString (UTF-8) value of @p c
+ * @return TQString (UTF-8) value of @p c
* @note NUL-terminated strings are rare on the handheld.
*/
@@ -140,12 +140,12 @@ namespace Pilot
return ((unsigned int)c<CATEGORY_COUNT);
}
- /** Returns the QString for the requested category @p i
- * in the category structure @p info. Returns @c QString::null
+ /** Returns the TQString for the requested category @p i
+ * in the category structure @p info. Returns @c TQString::null
* on error (bad pointer or bad category number). May also
@@ -140,12 +140,12 @@ namespace Pilot
* on error (bad pointer or bad category number). May also
- * return @c QString::null if the category name is empty.
+ * return @c TQString::null if the category name is empty.
*/